#
# spec file for package lldpd
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define lldpd_user lldpd
%define lldpd_group lldpd
%define lldpd_chroot %{_localstatedir}/run/lldpd
%define sover 4
%define libname liblldpctl%{sover}

%bcond_without xml
%bcond_without cdp
%bcond_without edp
%bcond_without sonmp
%bcond_without fdp
%bcond_without lldpmed
%bcond_without dot1
%bcond_without dot3
%bcond_without custom
%bcond_without snmp
%bcond_with    oldies
%bcond_without libbsd
%bcond_without systemd
%bcond_without system_libevent
%if 0%{?suse_version} > 1325
%ifarch x86_64 %ix86
%bcond_without seccomp
%endif
%else
%bcond_with    seccomp
%endif

Name:           lldpd
Version:        0.9.9
Release:        2.1
Summary:        Implementation of IEEE 802.1ab (LLDP)
# We have some GPL linux headers in include/linux, they are used on
# platforms where glibc headers are not recent enough
License:        MIT and GPL-2.0+
Group:          System/Daemons
Url:            http://vincentbernat.github.com/lldpd/
Source0:        http://media.luffy.cx/files/lldpd/%{name}-%{version}.tar.gz
Source1:        lldpd.sysconfig
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
%if %{with seccomp}
BuildRequires:  libseccomp-devel
%endif
%if %{with snmp}
BuildRequires:  net-snmp-devel
BuildRequires:  openssl-devel
%endif
%if %{with system_libevent}
BuildRequires:  libevent-devel
%endif
%if %{with xml}
BuildRequires:  libxml2-devel
%endif
%if %{with libbsd}
BuildRequires:  libbsd-devel
%endif
BuildRequires:  systemd-rpm-macros
PreReq:         %fillup_prereq
PreReq:         pwdutils

%description
This implementation provides LLDP sending and reception, supports VLAN
and includes an SNMP subagent that can interface to an SNMP agent
through AgentX protocol.

LLDP is an industry standard protocol designed to supplant proprietary
Link-Layer protocols such as Extreme EDP (Extreme Discovery Protocol)
and CDP (Cisco Discovery Protocol). The goal of LLDP is to provide an
inter-vendor compatible mechanism to deliver Link-Layer notifications
to adjacent network devices.

This daemon is also able to deal with CDP, FDP, SONMP and EDP
protocol. It also handles LLDP-MED extension.

%package -n %{libname}
Summary:        Implementation of IEEE 802.1ab - Shared library
License:        MIT
Group:          System/Libraries

%description -n %{libname}
This package provides the shared library for lldpd.

LLDP is an industry standard protocol designed to supplant proprietary
Link-Layer protocols such as Extreme EDP (Extreme Discovery Protocol)
and CDP (Cisco Discovery Protocol). The goal of LLDP is to provide an
inter-vendor compatible mechanism to deliver Link-Layer notifications
to adjacent network devices.


%package devel
Summary:        Implementation of IEEE 802.1ab - Tools and header files for developers
License:        MIT
Group:          Development/Languages/C and C++
Requires:       lldpd = %{version}-%{release}

%description devel
This package is required to develop alternate clients for lldpd.

LLDP is an industry standard protocol designed to supplant proprietary
Link-Layer protocols such as Extreme EDP (Extreme Discovery Protocol)
and CDP (Cisco Discovery Protocol). The goal of LLDP is to provide an
inter-vendor compatible mechanism to deliver Link-Layer notifications
to adjacent network devices.

%prep
%setup -q

%build
%configure \
%if %{with seccomp}
  --with-seccomp \
%endif
%if %{with snmp}
   --with-snmp \
%endif
%if %{with xml}
   --with-xml \
%endif
%if %{with libbsd}
   --with-libbsd \
%endif
%if %{with cdp}
   --enable-cdp \
%else
   --disable-cdp \
%endif
%if %{with edp}
   --enable-edp \
%else
   --disable-edp \
%endif
%if %{with sonmp}
   --enable-sonmp \
%else
   --disable-sonmp \
%endif
%if %{with fdp}
   --enable-fdp \
%else
   --disable-fdp \
%endif
%if %{with lldpmed}
   --enable-lldpmed \
%else
   --disable-lldpmed \
%endif
%if %{with dot1}
   --enable-dot1 \
%else
   --disable-dot1 \
%endif
%if %{with dot3}
   --enable-dot3 \
%else
   --disable-dot3 \
%endif
%if %{with custom}
   --enable-custom \
%else
   --disable-custom \
%endif
%if %{with oldies}
   --enable-oldies \
%else
   --disable-oldies \
%endif
   --with-privsep-user=%{lldpd_user} \
   --with-privsep-group=%{lldpd_group} \
   --with-privsep-chroot=%{lldpd_chroot} \
%if %{without systemd}
   --with-systemdsystemunitdir=no \
%else
   --with-systemdsystemunitdir=%{_unitdir} \
%endif
   --with-sysusersdir=no \
   --prefix=%{_usr} \
   --localstatedir=%{_localstatedir} \
   --sysconfdir=%{_sysconfdir} \
   --libdir=%{_libdir} \
   --docdir=%{_docdir}/lldpd \
   --enable-pie \
   --disable-static

[ -f %{_includedir}/net-snmp/agent/struct.h ] || touch src/struct.h
make %{?_smp_mflags} V=1

%install
%make_install
install -Dpm 0644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.lldpd
install -dm0755 %{buildroot}/%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rclldpd
rm -f %{buildroot}%{_libdir}/liblldpctl.la

%pre
# Create lldpd user/group
if getent group %{lldpd_group} >/dev/null 2>&1 ; then : ; else \
 %{_sbindir}/groupadd -r %{lldpd_group} > /dev/null 2>&1 || exit 1 ; fi
if getent passwd %{lldpd_user} >/dev/null 2>&1 ; then : ; else \
 %{_sbindir}/useradd -g %{lldpd_group} -M -r -s /sbin/nologin \
 -c "LLDP daemon" -d %{lldpd_chroot} %{lldpd_user} 2> /dev/null \
 || exit 1 ; fi

%service_add_pre lldpd.service

%post -n %{libname} -p /sbin/ldconfig
%postun  -n %{libname} -p /sbin/ldconfig

%post
%service_add_post lldpd.service
%fillup_only

%preun
%service_del_preun lldpd.service

%postun
%service_del_postun lldpd.service

%files
%dir %{_docdir}/lldpd
%doc %{_docdir}/lldpd/NEWS
%doc %{_docdir}/lldpd/LICENSE
%doc %{_docdir}/lldpd/ChangeLog
%doc %{_docdir}/lldpd/README.md
%doc %{_docdir}/lldpd/CONTRIBUTE.md
%{_sbindir}/lldpd
%{_sbindir}/lldpctl
%{_sbindir}/lldpcli
%{_datadir}/zsh
%{_datadir}/bash-completion
%{_mandir}/man8/lldp*.8%{ext_man}
%config %{_sysconfdir}/lldpd.d
%{_unitdir}/lldpd.service
%{_sbindir}/rclldpd
%{_fillupdir}/sysconfig.lldpd

%files -n %{libname}
%{_libdir}/liblldpctl.so.*

%files devel
%{_libdir}/liblldpctl.so
%{_libdir}/pkgconfig/lldpctl.pc
%{_includedir}/lldpctl.h
%{_includedir}/lldp-const.h

%changelog
* Mon Dec 11 2017 mpluskal@suse.com
- Enable seccomp for Factory
- Adjust default sysconfig to enable other protocols and self
  advertisment
- Do not create user/grou starting with underscore (_lldpd)
* Mon Dec  4 2017 mpluskal@suse.com
- Use fillupdir macro
- Enable libbsd
- Fix group for devel subpackage
* Mon Nov 27 2017 mpluskal@suse.com
- Clarify licensing and usage of some header files
- Enable support for libseccomp (disabled by default)
- Make buildign more verbose
* Wed Nov 22 2017 mardnh@gmx.de
- Created lldpd.changes file (converted inline Changelog via
  spec2changelog)
- Specfile cleanup (removed all stuff that is not relevant for
  recent (open)SUSE versions.)
* Tue Nov 21 2017 bernat@luffy.cx
- New upstream version.
* Sun Aug 20 2017 bernat@luffy.cx
- New upstream version.
* Sun Mar 19 2017 bernat@luffy.cx
- New upstream version.
* Sat Jan 21 2017 bernat@luffy.cx
- New upstream version.
* Fri Sep 30 2016 bernat@luffy.cx
- New upstream version.
* Fri Jun 17 2016 bernat@luffy.cx
- New upstream version.
* Sat May 21 2016 bernat@luffy.cx
- New upstream version.
* Sat Mar 19 2016 bernat@luffy.cx
- New upstream version.
* Sat Feb 20 2016 bernat@luffy.cx
- New upstream version.
* Fri Jan  1 2016 bernat@luffy.cx
- New upstream version.
- Do not rely on libnl3.
* Sun Dec 27 2015 bernat@luffy.cx
- New upstream version.
- Use system libnl3 when possible.
- Use system libevent when possible.
* Wed Sep  9 2015 bernat@luffy.cx
- New upstream version.
* Fri Aug  7 2015 bernat@luffy.cx
- New upstream version.
* Wed May 20 2015 bernat@luffy.cx
- New upstream version.
* Sat Apr  4 2015 bernat@luffy.cx
- New upstream version.
* Tue Dec 30 2014 bernat@luffy.cx
- New upstream version.
* Sat Nov 22 2014 bernat@luffy.cx
- New upstream version.
- Completion for bash and zsh.
* Wed Oct  8 2014 bernat@luffy.cx
- New upstream version.
- Completion for bash and zsh.
* Mon Jul 21 2014 bernat@luffy.cx
- New upstream version.
* Wed May 28 2014 bernat@luffy.cx
- New upstream version.
* Sun Apr 13 2014 bernat@luffy.cx
- New upstream version.
* Sun Nov 10 2013 bernat@luffy.cx
- New upstream version.
* Fri Jul 12 2013 bernat@luffy.cx
- New upstream version.
* Sat Jun 22 2013 bernat@luffy.cx
- New upstream version.
* Sun May 12 2013 bernat@luffy.cx
- New upstream version.
* Fri Apr 19 2013 bernat@luffy.cx
- New upstream version.
* Sat Jan 12 2013 bernat@luffy.cx
- New upstream version.
* Sun Jan  6 2013 bernat@luffy.cx
- New upstream version.
- Requires readline-devel.
- Ships lldpcli.
* Thu Sep 27 2012 bernat@luffy.cx
- New upstream version
- Do not require libevent, use embedded copy.
- Provide a -devel package.
* Fri Jun 11 2010 bernat@luffy.cx
- New upstream version
- Define bcond_without and with macros if not defined to be compatible
  with RHEL
- Requires useradd and groupadd
- Adapt to make it work with SuSE
- Provide an init script targetted at SuSE
- Build require lm_sensors-devel on RHEL
* Fri Mar 12 2010 bernat@luffy.cx
- New upstream version
- Add XML support
* Tue May 19 2009 bernat@luffy.cx
- Add variables
- Enable SNMP support
- Add _lldpd user creation
- Add initscript
- New upstream version
* Mon May 18 2009 dean.hamstead@optusnet.com.au
- Initial attempt
